==> BBmisc_1.1-125.tar.gz: BBmisc/R/save2.R <==
#' Save multiple objects to a file.
#' 
#' A simple wrapper for \code{save}. Understands key = value syntax to save 
#' objects using arbitrary variable names. All options of \code{\link[base]{save}}, 
#' except \code{list} and \code{envir}, are available and passed to 
#' \code{\link[base]{save}}.
#' 
#' @param file 
#'   File to save.
#' @param ... [\code{any}]\cr
#'   Will be converted to an environment and then passed to \code{\link[base]{save}}.
#' @param ascii
#'   See help of \code{\link[base]{save}}.
#' @param version
#'   See help of \code{\link[base]{save}}.
#' @param compress
#'   See help of \code{\link[base]{save}}.
#' @param compression_level
#'   See help of \code{\link[base]{save}}.
#' @param eval.promises
#'   See help of \code{\link[base]{save}}.
#' @param precheck
#'   See help of \code{\link[base]{save}}.
#' @return See help of \code{\link[base]{save}}.
#' @export
#' @examples
#' x <- 1
#' save2(y=x, file=tempfile())
save2 = function(file, ..., ascii = FALSE, version = NULL, compress = !ascii, 
  compression_level, eval.promises = TRUE, precheck = TRUE) {
  
  args = list(...)
  ns = names(args)
  ns.missing = (ns == "")
  if(any(ns.missing)) {
    ns.sub = as.character(substitute(list(...)))[-1L]
    ns[ns.missing] = ns.sub[ns.missing]
    names(args) = ns
  }

  ee = tryCatch(as.environment(args), 
    error = function(e) stopf("Unable to convert to environment (%s)", as.character(e)))
  save(list = ns, envir = ee, file = file, ascii = ascii, version = version, compress = compress,
       compression_level = compression_level, eval.promises = eval.promises, precheck = precheck)
}

==> BBmisc_1.1-164.tar.gz: BBmisc/R/save2.R <==
#' Save multiple objects to a file.
#'
#' A simple wrapper for \code{save}. Understands key = value syntax to save
#' objects using arbitrary variable names. All options of \code{\link[base]{save}},
#' except \code{list} and \code{envir}, are available and passed to
#' \code{\link[base]{save}}.
#'
#' @param file
#'   File to save.
#' @param ... [\code{any}]\cr
#'   Will be converted to an environment and then passed to \code{\link[base]{save}}.
#' @param ascii
#'   See help of \code{\link[base]{save}}.
#' @param version
#'   See help of \code{\link[base]{save}}.
#' @param compress
#'   See help of \code{\link[base]{save}}.
#' @param compression_level
#'   See help of \code{\link[base]{save}}.
#' @param eval.promises
#'   See help of \code{\link[base]{save}}.
#' @param precheck
#'   See help of \code{\link[base]{save}}.
#' @return See help of \code{\link[base]{save}}.
#' @export
#' @examples
#' x <- 1
#' save2(y=x, file=tempfile())
save2 = function(file, ..., ascii = FALSE, version = NULL, compress = !ascii,
  compression_level, eval.promises = TRUE, precheck = TRUE) {

  args = list(...)
  nargs = length(args)
  ns = names(args)
  if (is.null(ns)) {
    ns = character(nargs)
    ns.missing = rep(TRUE, nargs)
  } else {
    ns.missing = (ns == "")
  }
  if(any(ns.missing)) {
    ns.sub = as.character(substitute(deparse(...)))[-1L]
    ns[ns.missing] = ns.sub[ns.missing]
    names(args) = ns
  }

  ee = tryCatch(as.environment(args),
    error = function(e) stopf("Unable to convert to environment (%s)", as.character(e)))
  save(list = ns, envir = ee, file = file, ascii = ascii, version = version, compress = compress,
       compression_level = compression_level, eval.promises = eval.promises, precheck = precheck)
}
